#
# spec file for package kinfocenter6
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.10.0
%define qt6_version 6.7.0

%global __requires_exclude qt6qmlimport\\(org\\.kde\\.kinfocenter\\.private.*

%define rname kinfocenter
%bcond_without released
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
Name:           kinfocenter6
Version:        6.3.2
Release:        2.2
Summary:        Utility that provides information about a computer system
License:        GPL-2.0-or-later
URL:            https://www.kde.org/
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
# PATCH-FIX-OPENSUSE
Patch100:       0002-Look-for-binaries-in-Mesa-demos-path-as-well.patch
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
# For creating the post-install symlink
BuildRequires:  systemsettings6
BuildRequires:  cmake(KF6Auth) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6Solid) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(libusb-1.0)
Provides:       kinfocenter5 = %{version}
Obsoletes:      kinfocenter5 < %{version}
Obsoletes:      kinfocenter5-lang < %{version}
Requires:       kf6-kcmutils-imports >= %{kf6_version}

# needed for the fileindexermonitor
Requires:       kf6-baloo-imports >= %{kf6_version}
# The executable is now a link to systemsettings6
Requires:       systemsettings6
# lspci is called by the PCI KCM
Requires:       pciutils
# GLX is always present
Requires:       /usr/bin/glxinfo
# Vulkan might not be needed
Requires:       (/usr/bin/vulkaninfo if libvulkan1)
# Plasma Wayland is always installed
Requires:       /usr/bin/wayland-info
# Provides information on X
Requires:       /usr/bin/xdpyinfo
# Note: Not available as /usr/bin/eglinfo yet (boo#1195695)
Recommends:     /usr/bin/eglinfo
# clinfo if OpenCL is installed
Requires:       (clinfo if libOpenCL1)
# dmidecode is used to show information on memory
Recommends:     dmidecode
# The "Firmware Security" page does fwupdmgr ... | aha | ...
Requires:       (aha if fwupd)
# EDID kcm requires di-edid-decode
Recommends:     libdisplay-info-tools >= 0.2.0

%description
KDE Utility that provides information about a computer system.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name --with-html

%files
%license LICENSES/*.txt
%doc %lang(en) %{_kf6_htmldir}/en/kinfocenter/
%{_kf6_applicationsdir}/kcm_about-distro.desktop
%{_kf6_applicationsdir}/kcm_energyinfo.desktop
%{_kf6_applicationsdir}/org.kde.kinfocenter.desktop
%{_kf6_appstreamdir}/org.kde.kinfocenter.appdata.xml
%{_kf6_bindir}/kinfocenter
%{_kf6_libdir}/libKInfoCenterInternal.so
%{_kf6_plugindir}/plasma/kcms/kcm_about-distro.so
%{_kf6_plugindir}/plasma/kcms/kcm_energyinfo.so
%dir %{_kf6_plugindir}/plasma/kcms/kinfocenter/
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_audio_information.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_block_devices.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_cpu.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_edid.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_egl.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_firmware_security.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_glx.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_interrupts.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_kwinsupportinfo.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_memory.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_network.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_opencl.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_pci.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_samba.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_usb.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_vulkan.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_wayland.so
%{_kf6_plugindir}/plasma/kcms/kinfocenter/kcm_xserver.so
%{_kf6_qmldir}/org/kde/kinfocenter/
%{_kf6_sharedir}/dbus-1/system-services/org.kde.kinfocenter.dmidecode.service
%{_kf6_dbuspolicydir}/org.kde.kinfocenter.dmidecode.conf
%dir %{_kf6_sharedir}/kinfocenter/
%dir %{_kf6_sharedir}/kinfocenter/edid
%{_kf6_sharedir}/kinfocenter/edid/edid.sh
%{_kf6_sharedir}/kinfocenter/categories/
%{_kf6_sharedir}/kinfocenter/firmware_security/
%{_kf6_sharedir}/polkit-1/actions/org.kde.kinfocenter.dmidecode.policy
%{_kf6_libexecdir}/kauth/kinfocenter-dmidecode-helper
%{_libexecdir}/kinfocenter-opengl-helper

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en

%changelog
* Sat Mar  1 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Downgrade dmidecode (not available on all archs) and
  /usr/bin/eglinfo (boo#1238199) to recommends again
* Fri Feb 28 2025 Enrico Belleri <kilgore.trout@idesmi.eu>
- Update spec to the current state of things:
  * Requires aha if fwupd
  * Requires clinfo if OpenCL is installed
  * Requires dmidecode to show device Product Name, Serial Number
    and information on system memory
  * Recommends libdisplay-info-tools (/usr/bin/di-edid-decode)
    for EDID kcm.
  * Requires /usr/bin/eglinfo, instead of Recommends.
  * Deprecate update-desktop-files
    (https://en.opensuse.org/openSUSE:Update-desktop-files_deprecation)
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1:
  * update version for new release
  * about: align gpu pills more neatly (kde#500355)
  * update version for new release
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- Changes since 6.3.0:
  * update version for new release
  * kcms/energy: Fix page size flickering (kde#480804)
* Thu Feb  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- Changes since 6.2.91:
  * update version for new release
  * CommandOutputKCM: Use correct newlines for HTML-styled content (kde#499069)
* Thu Jan 23 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.91
- Changes since 6.2.90:
  * update version for new release
  * cmake: Call cmake_minimum_required before project()
* Sat Jan 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.2.90
- Changes since 6.2.5:
  * update version for new release
  * Made KDocTools optional
  * It compiles fine without deprecated methods
  * update version for new release
  * energyinfo: Add "Charge Cycles" info
  * about-distro: align labels top
  * about-distro: hint gpu type
  * about-distro: gpu factorization
  * about-distro: new hint system
  * about-distro: support multiple GPUs (kde#491527)
  * Remove obsolete menu category files
  * update version for new release
  * appiumtests: fix wayland
  * Don't include quiet packages in feature_summary
  * Add "Documentation" as a category
  * update version for new release
  * add an edid module (kde#492523)
  * update version for new release
  * kcms/memory: use KAuth dmidecode helper
  * refactor(dmidecode-helper): support multiple methods
  * kcms: pull dmidecode-helper into a separate dir
  * tidy appstream version information
  * update version for new release
- Drop patches, now upstream:
  * 0001-kcms-pull-dmidecode-helper-into-a-separate-dir.patch
  * 0002-refactor-dmidecode-helper-support-multiple-methods.patch
  * 0003-kcms-memory-use-KAuth-dmidecode-helper.patch
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
  * appiumtests: fix wayland
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Thu Oct 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to fix the memory info page by switching from pkexec
  to KAuth:
  * 0001-kcms-pull-dmidecode-helper-into-a-separate-dir.patch
  * 0002-refactor-dmidecode-helper-support-multiple-methods.patch
  * 0003-kcms-memory-use-KAuth-dmidecode-helper.patch
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Changes since 6.1.5:
  * update version for new release
  * Use ECMDeprecationSettings
  * kcms: Add memory information KCM
  * update version for new release
  * remove dup appstream versions
  * update version for new release
  * appstream versions
  * update version for new release
  * Drop no longer needed KF6Widgets dependency
  * update version for new release
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
  * remove dup appstream versions
  * update version for new release
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
  * appstream versions
  * update version for new release
  * Drop no longer needed KF6Widgets dependency
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Too many changes to list here
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * remove dup version
  * update version for new release
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
  * revert premature appstream update
  * update version for new release
  * revert duplicate appstream entry
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * Remove sl documentation
  * update version for new release
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
  * Avoid QML singletons to work with shared QML engines (kde#480881)
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * about (dump): don't print wayland warnings after data dump
  * about (dump): show all windows in minimized mode
  * Fix translation not being shown
  * about-distro: remove separator lines
  * Remove extraFooterTopPadding usage
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Mon Jul 10 2023 Christophe Marin <christophe@krop.fr>
- Init kinfocenter6
